// $Id: arrow.cc,v 1.17 2002/05/17 08:13:46 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "misc.hh"

class Gtk_Arrow : public Gtk_Misc
{public:
	typedef Gtk_Misc Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_Arrow();
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const;
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return true; }
};

static Gtk_Arrow Gtk_Arrow;

const std::string Gtk_Arrow::TypeName(const Widget &w) const
{  return GtkPrefix()+"Arrow";
}

const std::string Gtk_Arrow::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"arrow.h";
}

Gtk_Arrow::Gtk_Arrow()
{  Writer["GtkArrow"]=this;
}

void Gtk_Arrow::ConstructionArgs(const Widget &w, CxxFile &f) const
{  f.FunctionArg() << Gtkmm2Namespace(w.getProperty("arrow_type","GTK_ARROW_RIGHT"));
   f.FunctionArg() << Gtkmm2Namespace(w.getProperty("shadow_type","GTK_SHADOW_OUT"));
}
